@@ -3,4 +3,7 @@ from cloudpy_sync import sync
 from cloudpy_run import run
 from cloudpy_clean import clean
 from cloudpy_config import Config
-from cloudpy_agent import Agent
\ No newline at end of file
+
+import platform
+if platform.system() != "Windows":
+    from cloudpy_agent import Agent
\ No newline at end of file
